#[non_exhaustive]pub enum Request<'a> {
Destroy,
GetIdleNotification {
timeout: u32,
seat: WlSeat,
},
GetInputIdleNotification {
timeout: u32,
seat: WlSeat,
},
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Destroy
destroy the manager
Destroy the manager object. All objects created via this interface remain valid.
This is a destructor, once sent this object cannot be used any longer.
GetIdleNotification
create a notification object
Create a new idle notification object.
The notification object has a minimum timeout duration and is tied to a seat. The client will be notified if the seat is inactive for at least the provided timeout. See ext_idle_notification_v1 for more details.
A zero timeout is valid and means the client wants to be notified as soon as possible when the seat is inactive.
GetInputIdleNotification
create a notification object
Create a new idle notification object to track input from the user, such as keyboard and mouse movement. Because this object is meant to track user input alone, it ignores idle inhibitors.
The notification object has a minimum timeout duration and is tied to a seat. The client will be notified if the seat is inactive for at least the provided timeout. See ext_idle_notification_v1 for more details.
A zero timeout is valid and means the client wants to be notified as soon as possible when the seat is inactive.
Only available since version 2 of the interface