pub struct ExtIdleNotifierV1 { /* private fields */ }Expand description
idle notification manager
This interface allows clients to monitor user idle status.
After binding to this global, clients can create ext_idle_notification_v1 objects to get notified when the user is idle for a given amount of time.
This interface has no events.
Implementations
Sourceimpl ExtIdleNotifierV1
impl ExtIdleNotifierV1
Sourcepub fn destroy(&self)
pub fn destroy(&self)
destroy the manager
Destroy the manager object. All objects created via this interface remain valid.
Sourcepub fn get_idle_notification<U, D: 'static>(
&self,
timeout: u32,
seat: &WlSeat,
qh: &QueueHandle<D>,
udata: U,
) -> ExtIdleNotificationV1
pub fn get_idle_notification<U, D: 'static>( &self, timeout: u32, seat: &WlSeat, qh: &QueueHandle<D>, udata: U, ) -> ExtIdleNotificationV1
create a notification object
Create a new idle notification object.
The notification object has a minimum timeout duration and is tied to a seat. The client will be notified if the seat is inactive for at least the provided timeout. See ext_idle_notification_v1 for more details.
A zero timeout is valid and means the client wants to be notified as soon as possible when the seat is inactive.
Sourcepub fn get_input_idle_notification<U, D: 'static>(
&self,
timeout: u32,
seat: &WlSeat,
qh: &QueueHandle<D>,
udata: U,
) -> ExtIdleNotificationV1
pub fn get_input_idle_notification<U, D: 'static>( &self, timeout: u32, seat: &WlSeat, qh: &QueueHandle<D>, udata: U, ) -> ExtIdleNotificationV1
create a notification object
Create a new idle notification object to track input from the user, such as keyboard and mouse movement. Because this object is meant to track user input alone, it ignores idle inhibitors.
The notification object has a minimum timeout duration and is tied to a seat. The client will be notified if the seat is inactive for at least the provided timeout. See ext_idle_notification_v1 for more details.
A zero timeout is valid and means the client wants to be notified as soon as possible when the seat is inactive.